Preferences/ShortcutsDialog.py

changeset 3670
f0cb7579c0b4
parent 3656
441956d8fce5
child 4021
195a471c327b
diff -r ac84ac3c0f05 -r f0cb7579c0b4 Preferences/ShortcutsDialog.py
--- a/Preferences/ShortcutsDialog.py	Sat Jul 05 11:41:14 2014 +0200
+++ b/Preferences/ShortcutsDialog.py	Sat Jul 05 12:13:23 2014 +0200
@@ -4,7 +4,7 @@
 #
 
 """
-Module implementing a dialog for the configuration of eric5's keyboard
+Module implementing a dialog for the configuration of eric6's keyboard
 shortcuts.
 """
 
@@ -25,7 +25,7 @@
 
 class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
     """
     Class implementing a dialog for the configuration of eric5's keyboard
     shortcuts.
     
     @signal updateShortcuts() emitted when the user pressed the dialogs OK
@@ -188,7 +188,7 @@
                 self.pluginCategoryItems.append(categoryItem)
         
         self.helpViewerItem = self.__generateCategoryItem(
-            self.tr("eric5 Web Browser"))
+            self.tr("eric6 Web Browser"))
         for act in e5App().getObject("DummyHelpViewer").getActions():
             self.__generateShortcutItem(self.helpViewerItem, act, True)
         
@@ -25,7 +25,7 @@
 class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
     """
-    Class implementing a dialog for the configuration of eric5's keyboard
+    Class implementing a dialog for the configuration of eric6's keyboard
     shortcuts.
     

eric ide

mercurial